import pytest
import logging
from ..lib.MonitoringBase import MonitoringBase  # Replace with your actual import path
from io import BytesIO

@pytest.fixture
def monitoring_base():
    return MonitoringBase()

def test_send_email_with_attachment(monitoring_base, caplog):
    caplog.set_level(logging.INFO)
    
    # Create a small sample Excel file in memory
    excel_content = BytesIO()
    excel_content.write(b'Test content for Excel file')
    excel_content.seek(0)
    
    file_bytes = excel_content.read()
    subject = "Test Subject"
    body = "This is a test email body."
    recipient = ""
    sender = ""
    cc = [""]
    connection_string = ""

    # Call the method
    monitoring_base.send_email_with_attachment(connection_string, file_bytes, subject, body, recipient, sender, cc)

    # Check logs for what happened during the email sending process
    for record in caplog.records:
        print(record.levelname, record.message)
    
    # Ensure the test actually checked the relevant logging messages
    assert any("Initializing EmailClient" in record.message for record in caplog.records)
    assert any("Encoding file to base64" in record.message for record in caplog.records)
    assert any("Sending email" in record.message for record in caplog.records)
    assert any("Email sent successfully" in record.message for record in caplog.records)



import pytest
import requests
from ..lib.collections.ShopifyProducts import ShopifyProducts

STORE_NAME = ""
ACCESS_TOKEN = ""

@pytest.fixture
def shopify_products():
    """
    Fixture for creating an instance of the ShopifyProducts class.

    Returns:
        ShopifyProducts: An instance of the ShopifyProducts class with the specified store name and access token.
    """
    return ShopifyProducts(STORE_NAME, ACCESS_TOKEN)

def test_get_products(shopify_products):
    products = shopify_products.get_products(5)
    assert isinstance(products['data']['products']['edges'], list)
    if products:
        assert 'id' in products['data']['products']['edges'][0]['node']
        assert 'title' in products['data']['products']['edges'][0]['node']


# def test_get_product(shopify_products):
    
#     if products:
#         product_id = products['data']['products']['edges'][0]['node']['id']
#         product = shopify_products.get_product(product_id)
#         assert product is not None
#         assert 'id' in product
#         assert product['id'] == product_id

def test_create_product(shopify_products):
    product_title="shoes for men"
    response = shopify_products.create_product(product_title)
    assert product_title in response['data']['productCreate']['product']['title'], "Product not created"
        

def test_delete_product(shopify_products):

    # deletes the latest created product by previous test
    products = shopify_products.get_products(1,sort=True)
    last_product_id = products[0]['node']['id']
    created = shopify_products.delete_product(last_product_id)

    if 'product' in created:
        assert True

def test_update_product(shopify_products):
    # Fetch the list of products
    products = shopify_products.get_products()
    assert products is not None and len(products) > 0, "No products found"
    
    if products:
        product_id = products[0]['id']
        
        # Update the product
        original_product = products[0]

        original_title = original_product['title']
        new_title = "NEW PROUCT TILE TEST"
        updated_product = original_product
        graph_id_product = original_product['admin_graphql_api_id']
        shopify_products.update_product_title(new_title,graph_id_product)
        
        # Fetch the updated product
        updated_product = shopify_products.get_product(product_id)
        
        # Assertions to verify the update
        assert updated_product is not None, "Updated product is None"
        assert updated_product['title'] == new_title, f"Product title was not updated: expected {new_title}, got {updated_product['title']}"
        
        # Revert the product title to original 
        shopify_products.update_product_title(original_title,graph_id_product)
        reverted_product = shopify_products.get_product(product_id)
        assert reverted_product['title'] == original_title, "Failed to revert product title"


def test_get_product_by_sku(shopify_products):
    response = shopify_products.get_id_from_sku("VN-01-burgandy-4")
    if response['data']['productVariants']['edges']:
        # id = response['data']['productVariants']['edges'][0]['node']['id']
        assert True


import pytest
from ..lib.collections.ShopifyInventory import ShopifyInventory
from ..lib.collections.ShopifyProducts import ShopifyProducts

from unittest.mock import patch, Mock

STORE_NAME = ""
ACCESS_TOKEN = ""

@pytest.fixture
def shopify_inventory():
    """
    Returns an instance of the ShopifyInventory class initialized with the given STORE_NAME and ACCESS_TOKEN.
    
    :return: An instance of the ShopifyInventory class.
    :rtype: ShopifyInventory
    """
    return ShopifyInventory(STORE_NAME, ACCESS_TOKEN)


@pytest.fixture
def shopify_products():
    """
    Fixture for creating an instance of the ShopifyProducts class.

    Returns:
        ShopifyProducts: An instance of the ShopifyProducts class with the specified store name and access token.
    """
    return ShopifyProducts(STORE_NAME, ACCESS_TOKEN)

def test_fetch_inventory_levels(shopify_inventory):
    response = shopify_inventory.fetch_inventory_levels()

    assert 'data' in response
    assert 'inventoryLevels' in str(response['data']) # Null inventory level case

    ## case we have set invetory level
    # assert 'inventoryLevels' in response['data']['shop']['fulfillmentServices']['location']['inventoryLevels']

def test_set_item_quantity(
        shopify_inventory,
        shopify_products
        ):

    # ## inventory_item_id tekhdhou
    # # You need to provide a valid item_id and location_id for this test to work
    # inventoryItemId = "9545300345106"
    # location_id = "gid://shopify/Location/98855649554"
    # response = shopify_inventory.set_item_quantity(inventoryItemId, location_id, 50)
    # assert 'data' in response
    # assert 'inventoryAdjustQuantity' in response['data'] 

    products = shopify_products.get_products()
    assert products is not None and len(products) > 0, "No products found"
    
    if products:
        product_id = products[0]['id']
        inventoryItemId = products[0]['variants'][0]['inventory_item_id']
        inventory = shopify_inventory.fetch_inventory_levels()
        edges = inventory['data']['shop']['fulfillmentServices'][0]['location']['inventoryLevels']['edges']
        inventory_levels = [item['node']['id'] for item in edges]


# def test_set_item_quantity_success(shopify_inventory):
#     with patch('requests.post') as mock_post:
#         mock_response = Mock()
#         mock_response.json.return_value = {
#             "data": {
#                 "inventoryAdjustQuantity": {
#                     "inventoryLevel": {
#                         "available": 100
#                     },
#                     "userErrors": []
#                 }
#             }
#         }
#         mock_response.status_code = 200
#         mock_post.return_value = mock_response

#         response = shopify_inventory.set_item_quantity("inventory_item_id", "location_id", 100)
#         assert response["data"]["inventoryAdjustQuantity"]["inventoryLevel"]["available"] == 100
#         assert mock_post.called_once()
#         assert mock_post.call_args[1]["headers"] == shopify_inventory.headers